@define-color documents_collection_bg #000000;

/* gnome-documents */

.documents-collection-icon {
    background-color: @documents_collection_bg;
    border-radius: 8px;
}

/* Epiphany */

EphyToolbar .location-entry .button {
    border-image-source: url("borders/generic-border-dark.png");
}

EphyToolbar .location-entry .button:backdrop,
EphyToolbar .location-entry .button:backdrop:first-child,
EphyToolbar .location-entry .button:backdrop:hover,
EphyToolbar .location-entry .button:backdrop:hover:first-child {
    border-image-source: url("borders/generic-border-backdrop-dark.png");
}
